@@ -3,14 +3,14 @@ package Sah::Schema::filename;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-11'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem file name',
     'x.completion' => ['filename'],
     prefilters => [
-        'Str::expand_tilde_when_on_unix',
-        'Str::strip_slashes_when_on_unix',
+        'Path::expand_tilde_when_on_unix',
+        'Path::strip_slashes_when_on_unix',
     ],
 }, {}];
 
@@ -29,7 +29,7 @@ Sah::Schema::filename - Filesystem file name
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2020-02-11.
+This document describes version 0.013 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2020-02-11.
 
 =head1 HOMEPAGE
 
